<?php

namespace fielddayWidget\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Image_Size;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class ElementorfielddayFeaturedActivities extends Widget_Base
{
    /* settings variable */

    private $settings;

    public function get_name()
    {
        return 'elementor-activities';
    }

    public function get_title()
    {
        return __('Fieldday Activities', 'fieldday');
    }

    public function get_icon()
    {
        return 'eicon-posts-justified';
    }

    protected function _register_controls()
    {

        $this->wpcap_content_layout_options();

        $this->wpcap_description_options();
        $this->wpcap_bringingNeeds_options();
        $this->wpcap_routine_options();
        $this->wpcap_age_options();
        $this->wpcap_date_options();
        $this->wpcap_discount_options();
        $this->wpcap_design_options();
        $this->wpcap_button_options();
    }

    /**
     * Content Layout Options.
     */
    private function wpcap_content_layout_options()
    {

        $this->start_controls_section(
            'section_layout', [
                'label' => esc_html__('Layout', 'fieldday'),
            ]
        );

        $this->add_control(
            'activity_layout', [
                'label' => __('View', 'fieldday'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __('1 Column view', 'fieldday'),
                    '2' => __('2 Columns view', 'fieldday'),
                    '3' => __('3 Colums view', 'fieldday'),
                    '4' => __('4 Columns view', 'fieldday'),
                    '5' => __('5 Columns view', 'fieldday'),
                    '6' => __('6 Columns view', 'fieldday')
                ],
                'default' => '3'
            ]
        );
        $this->add_control(
            'activity_style', [
                'label' => __('Style', 'fieldday'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'alternate' => __('Alternate', 'fieldday'),
                    'simple' => __('Simple', 'fieldday')
                ],
                'default' => '3'
            ]
        );
        $this->add_control(
            'show_image', [
                'label' => __('Image', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_tag', [
                'label' => __('Title HTML Tag', 'fieldday'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'span' => 'span',
                    'p' => 'p',
                ],
                'default' => 'h3',
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }

    private function wpcap_image_options()
    {
        $this->start_controls_section(
            'section_image_design_options', [
                'label' => __('Image Options', 'fieldday'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'activity_image_effect', [
                'label' => esc_html__('Hover Effect', 'fieldday'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' => esc_html__('None', 'fieldday'),
                    'km_zoom-in' => esc_html__('Zoom In', 'fieldday'),
                    'km_zoom-out' => esc_html__('Zoom Out', 'fieldday'),
                    'km_blur' => esc_html__('Blur', 'fieldday'),
                    'km_slide' => esc_html__('Slide', 'fieldday'),
                    'km_rotate' => esc_html__('Rotate', 'fieldday'),
                    'km_flashing' => esc_html__('Flashing', 'fieldday'),
                    'km_shine' => esc_html__('Shine', 'fieldday'),
                    'km_circle' => esc_html__('Circle', 'fieldday')
                ],
                'default' => 'km_blur',
            ]
        );
        $this->add_control(
            'activity_image_overlay',
            [
                'label' => __('Image Overlay', 'elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_featured_session_img::after' => 'background: {{VALUE}};',
                ]
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'img_border',
                'label' => __('Border', 'plugin-domain'),
                'selector' => '{{WRAPPER}} .km_single_featured_activity .km_featured_session_img',
            ]
        );
        $this->add_control(
            'image_border_radious', [
                'label' => __('Border Radius', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_featured_session_img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'image_dimension',
            [
                'label' => __( 'Image Dimension', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::IMAGE_DIMENSIONS,
                'description' => __( 'Crop the original image size to any custom size. Set custom width or height to keep the original size ratio.', 'plugin-name' ),
                'default' => [
                        'width' => '',
                        'height' => '',
                ],
            ]
        );
        $this->add_control(
            'default_image',
            [
                'label' => __('Default Image', 'fieldday'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->end_controls_section();
    }


    private function wpcap_bringingNeeds_options()
    {
        $this->start_controls_section(
            'section_needs_options', [
                'label' => __('Bringing Needs', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_bringing_needs', [
                'label' => __('Show Bringing Needs', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'description_needs_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Bringing Needs', 'fieldday'),
                'condition' => [
                    'show_bringing_needs' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_needs_max_words', [
                'label' => __('Max Words', 'fieldday'),
                'type' => Controls_Manager::NUMBER,
                'default' => 20,
                'condition' => [
                    'show_bringing_needs' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_needs_readmore', [
                'label' => __('Read More Text', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('read more', 'fieldday'),
                'condition' => [
                    'show_bringing_needs' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }
    private function wpcap_age_options()
    {
        $this->start_controls_section(
            'section_age_options', [
                'label' => __('Age Group', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_age_group', [
                'label' => __('Show Age Group', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'description_age_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Ages', 'fieldday'),
                'condition' => [
                    'show_age_group' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'description_age_year_txt', [
                'label' => __('year text', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('yr', 'fieldday'),
                'condition' => [
                    'show_age_group' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }
    private function wpcap_date_options()
    {
        $this->start_controls_section(
            'section_dates_options', [
                'label' => __('Available Dates', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_available_dates', [
                'label' => __('Show Dates', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'available_dates_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('View Dates', 'fieldday'),
                'condition' => [
                    'show_available_dates' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'calander_icon',
            [
                'label' => __( 'Calander Icon', 'text-domain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'far fa-calendar-alt fa-2x',
                    'library' => 'solid',
                ],
                'condition' => [
                    'show_available_dates' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }
    private function wpcap_discount_options()
    {
        $this->start_controls_section(
            'section_discount_options', [
                'label' => __('Discounts', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_discount', [
                'label' => __('Show Dates', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'discount_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Discounts', 'fieldday'),
                'condition' => [
                    'show_discount' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }
    private function wpcap_routine_options()
    {
        $this->start_controls_section(
            'section_routine_options', [
                'label' => __('Daily Routine', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_daily_routine', [
                'label' => __('Show Description', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'description_routine_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Daily Routine', 'fieldday'),
                'condition' => [
                    'show_daily_routine' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_routine_max_words', [
                'label' => __('Max Words', 'fieldday'),
                'type' => Controls_Manager::NUMBER,
                'default' => 20,
                'condition' => [
                    'show_daily_routine' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_routine_readmore', [
                'label' => __('Read More Text', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('read more', 'fieldday'),
                'condition' => [
                    'show_daily_routine' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }
    private function wpcap_description_options()
    {
        $this->start_controls_section(
            'section_description_options', [
                'label' => __('Description', 'fieldday'),
            ]
        );
        $this->add_control(
            'show_description', [
                'label' => __('Show Description', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'description_exp_title', [
                'label' => __('Title', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Class Experience', 'fieldday'),
                'condition' => [
                    'show_description' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_exp_max_words', [
                'label' => __('Max Words', 'fieldday'),
                'type' => Controls_Manager::NUMBER,
                'default' => 20,
                'condition' => [
                    'show_description' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'description_exp_readmore', [
                'label' => __('Read More Text', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('read more', 'fieldday'),
                'condition' => [
                    'show_description' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }

    private function boxDesignOptions()
    {
        $this->start_controls_section(
            'section_box_design_options', [
                'label' => __('Box Options', 'fieldday'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'entrance_animation',
            [
                'label' => __('Entrance Animation', 'fieldday'),
                'type' => \Elementor\Controls_Manager::ANIMATION,
                'prefix_class' => 'animated ',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'label' => __( 'Background', 'plugin-domain' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .km_single_featured_activity',
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => __('Border', 'plugin-domain'),
                'selector' => '{{WRAPPER}} .km_single_featured_activity',
            ]
        );
        $this->add_control(
            'box-radious', [
                'label' => __('Border Radius', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'box-padding', [
                'label' => __('Box Padding', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'box-margin', [
                'label' => __('Box margin', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => ['5px'],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __('Box Shadow', 'plugin-domain'),
                'selector' => '{{WRAPPER}} .km_single_featured_activity',
            ]
        );
        $this->end_controls_section();
    }

    private function titleDesginOptions()
    {
        $this->start_controls_section(
                'section_design_options', [
                    'label' => __('Title', 'elementor'),
                    'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'title_color',
                [
                    'label' => __('Color', 'elementor'),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .km_featured_activity_title' => 'color: {{VALUE}};',
                    ]
                ]
        );
        $this->add_control(
            'title-margin', [
                'label' => __('margin', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_featured_activity_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => ['5px'],
            ]
        );
        $this->add_control(
            'title-padding', [
                'label' => __('Padding', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_featured_activity_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __('Typography', 'plugin-domain'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .km_featured_activity_title',
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__( 'Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'elementor' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'elementor' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'elementor' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'elementor' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .km_featured_activity_title' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
    }

    private function contentDesignOptions()
    {
        $this->start_controls_section(
                'section_design_options_description', [
                'label' => __('Content', 'elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label' => __('Heading Color', 'elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .km_act_heading' => 'color: {{VALUE}};',
                ]
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'heading_typography',
                'label' => __('Heading Typography', 'plugin-domain'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .km_act_heading',
            ]
        );

        $this->add_responsive_control(
            'heading_align',
            [
                'label' => esc_html__( 'Heading Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                            'title' => esc_html__( 'Left', 'elementor' ),
                            'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                            'title' => esc_html__( 'Center', 'elementor' ),
                            'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                            'title' => esc_html__( 'Right', 'elementor' ),
                            'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                            'title' => esc_html__( 'Justified', 'elementor' ),
                            'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                        '{{WRAPPER}} .km_act_heading' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => __('Text Color', 'elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .km_activity_text' => 'color: {{VALUE}};',
                ]
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'label' => __('Text Typography', 'plugin-domain'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .km_activity_text',
            ]
        );

        $this->add_responsive_control(
            'text_align',
            [
                'label' => esc_html__( 'Text Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'elementor' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'elementor' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'elementor' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'elementor' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .km_activity_text' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'discount-padding', [
                'label' => __('Padding', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_activity_discounts, {{WRAPPER}} .km_activity_agegroup, {{WRAPPER}} .km_activity_available_dates, {{WRAPPER}} .km_activity_description, {{WRAPPER}} .km_activity_bringing_needs, {{WRAPPER}} .km_activity_daily_routine' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_discount' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'discount-margin', [
                'label' => __('margin', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_activity_discounts, {{WRAPPER}} .km_activity_agegroup, {{WRAPPER}} .km_activity_available_dates, {{WRAPPER}} .km_activity_description, {{WRAPPER}} .km_activity_bringing_needs, {{WRAPPER}} .km_activity_daily_routine' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => ['5px'],
                'condition' => [
                    'show_discount' => 'yes',
                ],
            ]
        );
        $this->end_controls_section();
    }

    private function buttonDesignOptions()
    {
        //button controls
        $this->start_controls_section(
                'section_btn_design_options', [
                'label' => __('Button', 'elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'btn_text_typography',
                'label' => __('Typography', 'plugin-domain'),
                'scheme' => Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .km_activity_pu_btn .km_purchase_btn',
            ]
        );

        $this->add_responsive_control(
            'btn_align',
            [
                'label' => esc_html__( 'Alignment', 'elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                            'title' => esc_html__( 'Left', 'elementor' ),
                            'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                            'title' => esc_html__( 'Center', 'elementor' ),
                            'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                            'title' => esc_html__( 'Right', 'elementor' ),
                            'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                            'title' => esc_html__( 'Justified', 'elementor' ),
                            'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                        '{{WRAPPER}} .km_activity_pu_btn' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'button_color',
            [
                'label' => __('Color', 'elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_purchase_btn' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'button_bg-color',
            [
                'label' => __('Background Color', 'elementor'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_purchase_btn' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'button_border',
                'label' => __('Border', 'plugin-domain'),
                'selector' => '{{WRAPPER}} .km_single_featured_activity .km_purchase_btn',
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'button_border_radious', [
                'label' => __('Border Radius', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_purchase_btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'button-padding', [
                'label' => __('Padding', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_purchase_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ]
            ]
        );
        $this->add_control(
            'button-margin', [
                'label' => __('Margin', 'post-grid-elementor-addon'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .km_single_featured_activity .km_activity_pu_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ]
            ]
        );
        $this->end_controls_section();
    }


    /**
     * design controls
     */
    private function wpcap_design_options()
    {
        $this->titleDesginOptions();
        $this->contentDesignOptions();
        $this->wpcap_image_options();
        $this->boxDesignOptions();
        $this->buttonDesignOptions();
    }

    private function wpcap_button_options()
    {
        $this->start_controls_section(
            'section_button_options', [
                'label' => __('Button', 'fieldday'),
            ]
        );

        $this->add_control(
            'show_purchase_btn', [
                'label' => __('Show Button', 'fieldday'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'fieldday'),
                'label_off' => __('Hide', 'fieldday'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'button_text', [
                'label' => __('text', 'fieldday'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Purchase', 'fieldday'),
                'condition' => [
                    'show_purchase_btn' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }
    private function displayActivitiesList($featuredActivities)
    {
        $this->settings = $this->get_active_settings();
        $layoutColumns = $this->settings['activity_layout'];
        $style = fieldday()->engine->getValue('activity_style', $this->settings, false);
        $styleClass = "km_activity_simple";
        if($style == 'alternate') {
            $styleClass = "km_activity_alternate";
        }
        $layoutclass = ["layout_{$layoutColumns}_columns", $this->settings['activity_image_effect']];

        print "<div style='flex-wrap:wrap;' class='km_featured_activities km_row {$styleClass}'>";
        foreach ($featuredActivities as $key => $activity)
        {
            print "<div class='km_single_featured_activity ". implode(" ", $layoutclass) ."'>";
                $this->activityTitle($activity);
                print "<div class='km_row km_activity_row'>";
                    print "<div class='km_col_5'>";
                        $this->displayFeatureImage($activity);
                        print "<div class='km_row km_activity_meta'>";
                            $this->displayAgeGroup($activity);
                            $this->displayDiscounts($activity);
                            $this->displayAvailableDates($activity);
                        print "</div>";

                    print "</div>";
                    print "<div class='km_col_7'>";
                        $this->displayDescription($activity);
                        $this->displayBringingNeeds($activity);
                        $this->displayDailyRouteen($activity);
                        $this->displayPurchaseButton($activity);
                    print "</div>";
                print "</div>";
            print "</div>";
        }
        print "</div>";
    }

    protected function render($instance = [])
    {
        $featuredActivities = fieldday()->api->getFeaturedActivities([]);
        if ($featuredActivities->statusCode !== 200)
        {
            echo fieldday()->engine->displayFlash('error', __($featuredActivities->message, 'fieldday'));
            return;
        }

        $this->displayActivitiesList($featuredActivities->data);
    }

    /**
     * Display activity Title
     * @param Object $activity
     * @return String Html output
     */
    private function activityTitle($activity)
    {
        if ($this->settings['show_title'] == 'yes')
        {
            print wp_sprintf("<%s class='km_featured_activity_title'>%s</%s>", $this->settings['title_tag'], $activity->title, $this->settings['title_tag']);
        }
    }

    /**
     * Display session Image
     * @param object $activity
     *
     * @return String Html output
     */
    private function displayFeatureImage($activity)
    {
        $photos = $activity->photosURL;
        $thumburl = $photos[0]->original;
        if (!count($photos))
        {
            $thumburl = $this->settings['default_image']['url'];
        }
        if ($this->settings['show_image'] == 'yes' && $thumburl)
        {
            print wp_sprintf('<div class="km_featured_session_img"><img style="width:%s; height:%s" src="%s" class="img responsive-img"></div>', $this->settings['image_dimension']['width'], $this->settings['image_dimension']['height'], $thumburl);
        }
    }

    public function displayDescription($activity) {
        if ($this->settings['show_description']) {
            print "<div class='km_activity_description'>";
                print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['description_exp_title']);
                $readmoreLink = wp_sprintf('<a class="km_modal_link" data-description="%1$s" data-title="%2$s" href="#">%3$s</a>', $activity->overview, $activity->title, $this->settings['description_exp_readmore']);
                print wp_sprintf('<span class="km_activity_text">%1$s</span>', wp_trim_words($activity->overview, $this->settings['description_exp_max_words'], $readmoreLink));
            print "</div>";
        }
    }

    public function displayBringingNeeds($activity)
    {
        //echo "<pre>"; print_r($this->settings); echo "</pre>";
        if ($this->settings['show_bringing_needs']) {
            print "<div class='km_activity_bringing_needs'>";
                print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['description_needs_title']);
                $bringingNeedsArr = fieldday()->engine->getvalue('bringingNeedsArr', $activity, false);
                if($bringingNeedsArr) {
                    foreach ($bringingNeedsArr as $key => $bringingNeeds) {
                        print wp_sprintf('<span class="km_activity_text km_bringing_need_item" id="%1$s">%2$s</span>', $bringingNeeds->_id, $bringingNeeds->title);
                    }
                }else {
                    $readmoreLink = wp_sprintf('<a class="km_modal_link" data-description="%1$s" data-title="%2$s" href="#">%3$s</a>', $activity->bringingNeeds, $activity->title, $this->settings['description_needs_readmore']);
                    print wp_sprintf('<span class="km_activity_text">%1$s</span>', wp_trim_words($activity->bringingNeeds, $this->settings['description_needs_max_words'], $readmoreLink));
                }
            print "</div>";
        }
    }

    public function displayDailyRouteen($activity)
    {
        if ($this->settings['show_daily_routine']) {
            print "<div class='km_activity_daily_routine'>";
                print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['description_routine_title']);
                $dailyRoutineArr = fieldday()->engine->getvalue('dailyRoutineArr', $activity, false);
                if($dailyRoutineArr) {
                    foreach ($dailyRoutineArr as $key => $dailyRoutine) {
                        print wp_sprintf('<span class="km_activity_text km_daily_route_item" id="%1$s">%2$s</span>', $dailyRoutine->_id, $dailyRoutine->title);
                    }
                }else {
                    $readmoreLink = wp_sprintf('<a class="km_modal_link" data-description="%1$s" data-title="%2$s" href="#">%3$s</a>', $activity->dailyRoutine, $activity->title, $this->settings['description_routine_readmore']);
                    print wp_sprintf('<span class="km_activity_text">%1$s</span>', wp_trim_words($activity->dailyRoutine, $this->settings['description_routine_max_words'], $readmoreLink));
                }

            print "</div>";
        }
    }

    public function displayPurchaseButton($activity)
    {
        if($this->settings['show_purchase_btn']) {
            global $fielddaySetting;
            $purchase_page = get_permalink(fieldday()->engine->getValue('purchase_page', $fielddaySetting, false));
            $activity_link = add_query_arg(['activityId' => $activity->_id], $purchase_page);
            print "<div class='km_activity_pu_btn'>";
                print wp_sprintf('<a class="km_purchase_btn" href="%1$s">%2$s</a>', $activity_link, __($this->settings['button_text'], 'fieldday'));
            print "</div>";
        }
    }
    public function displayAgeGroup($activity)
    {
        if ($this->settings['show_age_group']) {
            print "<div class='km_activity_meta km_col_6'>";
                print "<div class='km_activity_agegroup'>";
                    print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['description_age_title']);
                    print wp_sprintf('<span class="km_activity_text">%1$s %3$s - %2$s %3$s</span>', $activity->ageRange->from, $activity->ageRange->to, $this->settings['description_age_year_txt']);
                print "</div>";
            print "</div>";

        }
    }

    public function displayAvailableDates($activity)
    {
        if ($this->settings['show_available_dates']) {
            print "<div class='km_activity_meta km_activity_available_dates km_col_6'>";
                print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['available_dates_title']);
                print wp_sprintf('<div class="km_icon_wrapper km_datepicker" data-date-from="%s" data-date-to="%s" data-modal-heading="%s">', $activity->date->from, $activity->date->to, $activity->title );
                    \Elementor\Icons_Manager::render_icon( $this->settings['calander_icon'], [ 'aria-hidden' => 'true' , 'class' => 'fa-2x'] );
		print "</div>";
            print "</div>";
        }
    }

    public function displayDiscounts($activity) {
        if ($this->settings['show_discount'] && $activity->offeringDiscounts) {
            print "<div class='km_activity_meta km_col_6'>";
                print "<div class='km_activity_discounts'>";
                    print wp_sprintf("<b class='km_act_heading'>%s</b>", $this->settings['discount_title']);
                    foreach ($activity->offeringDiscounts as $key => $discount)
                    {
                        print wp_sprintf('<span class="km_activity_text km_discount_lable">%s</span>', $discount);
                    }
                    //print wp_sprintf('<span class="km_activity_text">%1$s %3$s - %2$s %3$s</span>', $activity->ageRange->from, $activity->ageRange->to, $this->settings['description_age_year_txt']);
                print "</div>";
            print "</div>";

        }
    }
}
